

.. _dev_guide-label:

########################
HyperSpy Developer Guide
########################

.. toctree::
    :maxdepth: 2

    intro.rst
    git.rst
    testing.rst
    writing_docs.rst
    coding_style.rst
    lazy_computations.rst
    speeding_up_code.rst
    writing_extensions.rst
    useful_information.rst
